#[non_exhaustive]pub enum VolumeError {
DimensionMismatch {
expected: usize,
actual: usize,
dims_x: u32,
dims_y: u32,
dims_z: u32,
components: u32,
},
ZeroDimension {
x: u32,
y: u32,
z: u32,
},
InvalidSpacing {
x: f64,
y: f64,
z: f64,
},
ZeroComponents,
InconsistentSlice {
index: usize,
expected: usize,
actual: usize,
},
EmptySlices,
}Expand description
Errors produced during volume construction or access.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DimensionMismatch
The supplied data length does not match the declared dimensions.
Fields
ZeroDimension
At least one dimension was zero.
InvalidSpacing
At least one spacing value was zero or negative.
ZeroComponents
The number of components per voxel was zero.
InconsistentSlice
Slices have inconsistent lengths.
Fields
EmptySlices
No slices were provided.