VolumeError

Enum VolumeError 

#[non_exhaustive]
pub enum VolumeError { DimensionMismatch { expected: usize, actual: usize, dims_x: u32, dims_y: u32, dims_z: u32, components: u32, }, ZeroDimension { x: u32, y: u32, z: u32, }, InvalidSpacing { x: f64, y: f64, z: f64, }, ZeroComponents, InconsistentSlice { index: usize, expected: usize, actual: usize, }, EmptySlices, }
Errors produced during volume construction or access.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


DimensionMismatch

The supplied data length does not match the declared dimensions.

Fields

expected: usize

Expected number of scalars.

actual: usize

Actual number of scalars.

dims_x: u32

Volume dimensions used for the expectation.

dims_y: u32

Volume Y dimension.

dims_z: u32

Volume Z dimension.

components: u32

Number of components per voxel.



ZeroDimension

At least one dimension was zero.

Fields

x: u32

X dimension.

y: u32

Y dimension.

z: u32

Z dimension.



InvalidSpacing

At least one spacing value was zero or negative.

Fields

x: f64

X spacing.

y: f64

Y spacing.

z: f64

Z spacing.



ZeroComponents

The number of components per voxel was zero.



InconsistentSlice

Slices have inconsistent lengths.

Fields

index: usize

Slice index that was wrong.

expected: usize

Expected length.

actual: usize

Actual length.



EmptySlices

No slices were provided.